Index: src/core/SkPtrRecorder.h |
diff --git a/src/core/SkPtrRecorder.h b/src/core/SkPtrRecorder.h |
index 325471ea719999e9c7a57a9019f97cfaa68f095e..2d755e69e58d2818253ecf0b1d9734e6e14a8581 100644 |
--- a/src/core/SkPtrRecorder.h |
+++ b/src/core/SkPtrRecorder.h |
@@ -26,7 +26,7 @@ public: |
/** |
* Search for the specified ptr in the set. If it is found, return its |
* 32bit ID [1..N], or if not found, return 0. Always returns 0 for NULL. |
*/ |
uint32_t find(void*) const; |
@@ -34,7 +34,7 @@ public: |
* Add the specified ptr to the set, returning a unique 32bit ID for it |
* [1...N]. Duplicate ptrs will return the same ID. |
* |
* If the ptr is NULL, it is not added, and 0 is returned. |
*/ |
uint32_t add(void*); |
@@ -71,7 +71,7 @@ public: |
* Return the next ptr in the set or null if the end was reached. |
*/ |
void* next() { |
- return fIndex < fSet.fList.count() ? fSet.fList[fIndex++].fPtr : NULL; |
+ return fIndex < fSet.fList.count() ? fSet.fList[fIndex++].fPtr : nullptr; |
} |
private: |
@@ -85,7 +85,7 @@ protected: |
private: |
struct Pair { |
- void* fPtr; // never NULL |
+ void* fPtr; // never nullptr |
uint32_t fIndex; // 1...N |
}; |
@@ -26,7 +26,7 @@ public: |
/** |
* Search for the specified ptr in the set. If it is found, return its |
- * 32bit ID [1..N], or if not found, return 0. Always returns 0 for NULL. |
+ * 32bit ID [1..N], or if not found, return 0. Always returns 0 for nullptr. |
*/ |
uint32_t find(void*) const; |
@@ -34,7 +34,7 @@ public: |
* [1...N]. Duplicate ptrs will return the same ID. |
* |
- * If the ptr is NULL, it is not added, and 0 is returned. |
+ * If the ptr is nullptr, it is not added, and 0 is returned. |
*/ |
uint32_t add(void*); |